@@ -44,7 +44,15 @@ class NavRepTrainEnv(gym.Env):
     """ This class wraps the SOADRL env to make a RL ready simplified environment,
     compatible with navrep.
 
-    observation is (laser scan, [goal, vel])
+    Action space:
+        (x velocity, y velocity, theta velocity), all in [m/s]
+    Observation space:
+        (scan, robotstate)
+        scan:
+            360 degree lidar scan, 1080 rays,
+            with min angle of 0 (straight forwards), max angle of 2pi. [m]
+        robotstate
+            (goal x [m], goal y [m], vx [m/s], vy [m/s], vth [rad/s]) - all in robot frame
     """
     metadata = {'render.modes': ['human', 'rings']}
 
@@ -53,8 +61,10 @@ class NavRepTrainEnv(gym.Env):
         # gym env definition
         super(NavRepTrainEnv, self).__init__()
         self.action_space = spaces.Box(low=-1, high=1, shape=(3,), dtype=np.float32)
-        self.observation_space = spaces.Box(low=-np.inf, high=np.inf,
-                                            shape=(1080,), dtype=np.float32)
+        self.observation_space = spaces.Tuple((
+            spaces.Box(low=-np.inf, high=np.inf, shape=(1080,), dtype=np.float32),
+            spaces.Box(low=-np.inf, high=np.inf, shape=(5,), dtype=np.float32)
+        ))
         # parameters
         self.lidar_legs = lidar_legs
         self.silent = silent
